# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.get_knowledge_base_list_response_model import GetKnowledgeBaseListResponseModel
from ...types.http_validation_error import HttpValidationError
from ...types.knowledge_base_document_type import KnowledgeBaseDocumentType


class RawKnowledgeBaseClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        show_only_owned_documents: typing.Optional[bool] = None,
        types: typing.Optional[
            typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]
        ] = None,
        use_typesense: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetKnowledgeBaseListResponseModel]:
        """
        Get a list of available knowledge base documents

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            If specified, the endpoint returns only such knowledge base documents whose names start with this string.

        show_only_owned_documents : typing.Optional[bool]
            If set to true, the endpoint will return only documents owned by you (and not shared from somebody else).

        types : typing.Optional[typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]]
            If present, the endpoint will return only documents of the given types.

        use_typesense : typing.Optional[bool]
            If set to true, the endpoint will use typesense DB to search for the documents).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetKnowledgeBaseListResponseModel]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/convai/knowledge-base",
            method="GET",
            params={
                "cursor": cursor,
                "page_size": page_size,
                "search": search,
                "show_only_owned_documents": show_only_owned_documents,
                "types": types,
                "use_typesense": use_typesense,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetKnowledgeBaseListResponseModel,
                    construct_type(
                        type_=GetKnowledgeBaseListResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawKnowledgeBaseClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        show_only_owned_documents: typing.Optional[bool] = None,
        types: typing.Optional[
            typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]
        ] = None,
        use_typesense: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetKnowledgeBaseListResponseModel]:
        """
        Get a list of available knowledge base documents

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            If specified, the endpoint returns only such knowledge base documents whose names start with this string.

        show_only_owned_documents : typing.Optional[bool]
            If set to true, the endpoint will return only documents owned by you (and not shared from somebody else).

        types : typing.Optional[typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]]
            If present, the endpoint will return only documents of the given types.

        use_typesense : typing.Optional[bool]
            If set to true, the endpoint will use typesense DB to search for the documents).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetKnowledgeBaseListResponseModel]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/convai/knowledge-base",
            method="GET",
            params={
                "cursor": cursor,
                "page_size": page_size,
                "search": search,
                "show_only_owned_documents": show_only_owned_documents,
                "types": types,
                "use_typesense": use_typesense,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetKnowledgeBaseListResponseModel,
                    construct_type(
                        type_=GetKnowledgeBaseListResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AddChapterResponseModel,
    AddKnowledgeBaseResponseModel,
    AddProjectRequest,
    AddProjectResponseModel,
    AddPronunciationDictionaryResponseModel,
    AddPronunciationDictionaryResponseModelPermissionOnResource,
    AddSharingVoiceRequest,
    AddVoiceIvcResponseModel,
    AddVoiceResponseModel,
    AddWorkspaceGroupMemberResponseModel,
    AddWorkspaceInviteResponseModel,
    AdditionalFormatResponseModel,
    AdditionalFormats,
    Age,
    AgentCallLimits,
    AgentConfig,
    AgentConfigOverride,
    AgentConfigOverrideConfig,
    AgentMetadataResponseModel,
    AgentPlatformSettingsRequestModel,
    AgentPlatformSettingsResponseModel,
    AgentSimulatedChatTestResponseModel,
    AgentSummaryResponseModel,
    AgentTestingSettings,
    AgentTransfer,
    AgentWorkspaceOverridesInput,
    AgentWorkspaceOverridesOutput,
    Alignment,
    AllowlistItem,
    ArrayJsonSchemaPropertyInput,
    ArrayJsonSchemaPropertyInputItems,
    ArrayJsonSchemaPropertyOutput,
    ArrayJsonSchemaPropertyOutputItems,
    AsrConversationalConfig,
    AsrInputFormat,
    AsrProvider,
    AsrQuality,
    AudioNativeCreateProjectResponseModel,
    AudioNativeEditContentResponseModel,
    AudioNativeProjectSettingsResponseModel,
    AudioNativeProjectSettingsResponseModelStatus,
    AudioOutput,
    AudioOutputMulti,
    AudioWithTimestampsResponse,
    AuthConnectionLocator,
    AuthSettings,
    AuthorizationMethod,
    BadRequestErrorBody,
    BanReasonType,
    BatchCallDetailedResponse,
    BatchCallRecipientStatus,
    BatchCallResponse,
    BatchCallStatus,
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge,
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender,
    BreakdownTypes,
    BuiltInToolsInput,
    BuiltInToolsOutput,
    CaptionStyleCharacterAnimationModel,
    CaptionStyleCharacterAnimationModelEnterType,
    CaptionStyleCharacterAnimationModelExitType,
    CaptionStyleHorizontalPlacementModel,
    CaptionStyleHorizontalPlacementModelAlign,
    CaptionStyleModel,
    CaptionStyleModelTextAlign,
    CaptionStyleModelTextStyle,
    CaptionStyleModelTextWeight,
    CaptionStyleSectionAnimationModel,
    CaptionStyleSectionAnimationModelEnterType,
    CaptionStyleSectionAnimationModelExitType,
    CaptionStyleTemplateModel,
    CaptionStyleVerticalPlacementModel,
    CaptionStyleVerticalPlacementModelAlign,
    CaptionStyleWordAnimationModel,
    CaptionStyleWordAnimationModelEnterType,
    CaptionStyleWordAnimationModelExitType,
    ChapterContentBlockExtendableNodeResponseModel,
    ChapterContentBlockInputModel,
    ChapterContentBlockInputModelSubType,
    ChapterContentBlockResponseModel,
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
    ChapterContentBlockTtsNodeResponseModel,
    ChapterContentInputModel,
    ChapterContentParagraphTtsNodeInputModel,
    ChapterContentResponseModel,
    ChapterResponse,
    ChapterSnapshotExtendedResponseModel,
    ChapterSnapshotResponse,
    ChapterSnapshotsResponse,
    ChapterState,
    ChapterStatisticsResponse,
    ChapterWithContentResponseModel,
    ChapterWithContentResponseModelState,
    CharacterAlignmentModel,
    CharacterAlignmentResponseModel,
    CharacterUsageResponse,
    ClientEvent,
    ClientToolConfigInput,
    ClientToolConfigOutput,
    CloseConnection,
    CloseContext,
    CloseSocket,
    ConvAiDynamicVariable,
    ConvAiSecretLocator,
    ConvAiStoredSecretDependencies,
    ConvAiStoredSecretDependenciesAgentsItem,
    ConvAiStoredSecretDependenciesAgentsItem_Available,
    ConvAiStoredSecretDependenciesAgentsItem_Unknown,
    ConvAiStoredSecretDependenciesToolsItem,
    ConvAiStoredSecretDependenciesToolsItem_Available,
    ConvAiStoredSecretDependenciesToolsItem_Unknown,
    ConvAiUserSecretDbModel,
    ConvAiWebhooks,
    ConvAiWorkspaceStoredSecretConfig,
    ConversationChargingCommonModel,
    ConversationConfig,
    ConversationConfigClientOverrideConfigInput,
    ConversationConfigClientOverrideConfigOutput,
    ConversationConfigClientOverrideInput,
    ConversationConfigClientOverrideOutput,
    ConversationConfigOverride,
    ConversationConfigOverrideConfig,
    ConversationDeletionSettings,
    ConversationHistoryAnalysisCommonModel,
    ConversationHistoryBatchCallModel,
    ConversationHistoryElevenAssistantCommonModel,
    ConversationHistoryErrorCommonModel,
    ConversationHistoryEvaluationCriteriaResultCommonModel,
    ConversationHistoryFeedbackCommonModel,
    ConversationHistoryMetadataCommonModel,
    ConversationHistoryMetadataCommonModelPhoneCall,
    ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking,
    ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
    ConversationHistoryRagUsageCommonModel,
    ConversationHistorySipTrunkingPhoneCallModel,
    ConversationHistorySipTrunkingPhoneCallModelDirection,
    ConversationHistoryTranscriptCommonModelInput,
    ConversationHistoryTranscriptCommonModelInputRole,
    ConversationHistoryTranscriptCommonModelInputSourceMedium,
    ConversationHistoryTranscriptCommonModelInputToolResultsItem,
    ConversationHistoryTranscriptCommonModelOutput,
    ConversationHistoryTranscriptCommonModelOutputRole,
    ConversationHistoryTranscriptCommonModelOutputSourceMedium,
    ConversationHistoryTranscriptCommonModelOutputToolResultsItem,
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
    ConversationHistoryTranscriptOtherToolsResultCommonModelType,
    ConversationHistoryTranscriptSystemToolResultCommonModel,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess,
    ConversationHistoryTranscriptToolCallClientDetails,
    ConversationHistoryTranscriptToolCallCommonModel,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook,
    ConversationHistoryTranscriptToolCallMcpDetails,
    ConversationHistoryTranscriptToolCallWebhookDetails,
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput,
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
    ConversationHistoryTwilioPhoneCallModel,
    ConversationHistoryTwilioPhoneCallModelDirection,
    ConversationInitiationClientDataConfigInput,
    ConversationInitiationClientDataConfigOutput,
    ConversationInitiationClientDataInternal,
    ConversationInitiationClientDataInternalDynamicVariablesValue,
    ConversationInitiationClientDataRequestInput,
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
    ConversationInitiationClientDataRequestOutput,
    ConversationInitiationClientDataRequestOutputDynamicVariablesValue,
    ConversationInitiationClientDataWebhook,
    ConversationInitiationClientDataWebhookRequestHeadersValue,
    ConversationInitiationSource,
    ConversationInitiationSourceInfo,
    ConversationSignedUrlResponseModel,
    ConversationSimulationSpecification,
    ConversationSimulationSpecificationDynamicVariablesValue,
    ConversationSummaryResponseModel,
    ConversationSummaryResponseModelDirection,
    ConversationSummaryResponseModelStatus,
    ConversationTokenDbModel,
    ConversationTokenPurpose,
    ConversationTurnMetrics,
    ConversationalConfig,
    ConvertChapterResponseModel,
    ConvertProjectResponseModel,
    CreateAgentResponseModel,
    CreateAudioNativeProjectRequest,
    CreatePhoneNumberResponseModel,
    CreatePreviouslyGeneratedVoiceRequest,
    CreatePronunciationDictionaryResponseModel,
    CreateSipTrunkPhoneNumberRequest,
    CreateTranscriptRequest,
    CreateTwilioPhoneNumberRequest,
    CustomLlm,
    CustomLlmRequestHeadersValue,
    DashboardCallSuccessChartModel,
    DashboardCriteriaChartModel,
    DashboardDataCollectionChartModel,
    DataCollectionResultCommonModel,
    DeleteChapterRequest,
    DeleteChapterResponseModel,
    DeleteDubbingResponseModel,
    DeleteHistoryItemResponse,
    DeleteProjectRequest,
    DeleteProjectResponseModel,
    DeleteSampleResponse,
    DeleteVoiceResponseModel,
    DeleteVoiceSampleResponseModel,
    DeleteWorkspaceGroupMemberResponseModel,
    DeleteWorkspaceInviteResponseModel,
    DeleteWorkspaceMemberResponseModel,
    DependentAvailableAgentIdentifier,
    DependentAvailableAgentIdentifierAccessLevel,
    DependentAvailableToolIdentifier,
    DependentAvailableToolIdentifierAccessLevel,
    DependentPhoneNumberIdentifier,
    DependentUnknownAgentIdentifier,
    DependentUnknownToolIdentifier,
    DialogueInput,
    DialogueInputResponseModel,
    DoDubbingResponse,
    DocumentUsageModeEnum,
    DocxExportOptions,
    DubbedSegment,
    DubbingMediaMetadata,
    DubbingMediaReference,
    DubbingMetadataPageResponseModel,
    DubbingMetadataResponse,
    DubbingRenderResponseModel,
    DubbingResource,
    DynamicVariableAssignment,
    DynamicVariableUpdateCommonModel,
    DynamicVariablesConfig,
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
    EditChapterResponseModel,
    EditProjectResponseModel,
    EditVoiceResponseModel,
    EditVoiceSettingsRequest,
    EditVoiceSettingsResponseModel,
    EmbedVariant,
    EmbeddingModelEnum,
    EndCallToolConfig,
    EndCallToolResultModel,
    EvaluationSettings,
    EvaluationSuccessResult,
    ExportOptions,
    ExportOptions_Docx,
    ExportOptions_Html,
    ExportOptions_Pdf,
    ExportOptions_SegmentedJson,
    ExportOptions_Srt,
    ExportOptions_Txt,
    ExtendedSubscriptionResponseModelBillingPeriod,
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
    ExtendedSubscriptionResponseModelCurrency,
    FeatureStatusCommonModel,
    FeaturesUsageCommonModel,
    FeedbackItem,
    FinalOutput,
    FinalOutputMulti,
    FineTuningResponse,
    FineTuningResponseModelStateValue,
    FlushContext,
    ForcedAlignmentCharacterResponseModel,
    ForcedAlignmentResponseModel,
    ForcedAlignmentWordResponseModel,
    Gender,
    GenerateVoiceRequest,
    GenerationConfig,
    GetAgentEmbedResponseModel,
    GetAgentKnowledgebaseSizeResponseModel,
    GetAgentLinkResponseModel,
    GetAgentResponseModel,
    GetAgentResponseModelPhoneNumbersItem,
    GetAgentResponseModelPhoneNumbersItem_SipTrunk,
    GetAgentResponseModelPhoneNumbersItem_Twilio,
    GetAgentsPageResponseModel,
    GetAudioNativeProjectSettingsResponseModel,
    GetChapterRequest,
    GetChapterSnapshotsRequest,
    GetChaptersRequest,
    GetChaptersResponse,
    GetConvAiDashboardSettingsResponseModel,
    GetConvAiDashboardSettingsResponseModelChartsItem,
    GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess,
    GetConvAiDashboardSettingsResponseModelChartsItem_Criteria,
    GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection,
    GetConvAiSettingsResponseModel,
    GetConversationResponseModel,
    GetConversationResponseModelStatus,
    GetConversationsPageResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
    GetKnowledgeBaseFileResponseModel,
    GetKnowledgeBaseListResponseModel,
    GetKnowledgeBaseListResponseModelDocumentsItem,
    GetKnowledgeBaseListResponseModelDocumentsItem_File,
    GetKnowledgeBaseListResponseModelDocumentsItem_Text,
    GetKnowledgeBaseListResponseModelDocumentsItem_Url,
    GetKnowledgeBaseSummaryFileResponseModel,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseSummaryTextResponseModel,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseSummaryUrlResponseModel,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseTextResponseModel,
    GetKnowledgeBaseUrlResponseModel,
    GetLibraryVoicesResponse,
    GetPhoneNumberInboundSipTrunkConfigResponseModel,
    GetPhoneNumberOutboundSipTrunkConfigResponseModel,
    GetPhoneNumberResponse,
    GetPhoneNumberSipTrunkResponseModel,
    GetPhoneNumberTwilioResponseModel,
    GetProjectRequest,
    GetProjectsRequest,
    GetProjectsResponse,
    GetPronunciationDictionariesMetadataResponseModel,
    GetPronunciationDictionariesResponse,
    GetPronunciationDictionaryMetadataResponse,
    GetPronunciationDictionaryMetadataResponseModelPermissionOnResource,
    GetPronunciationDictionaryResponse,
    GetSpeechHistoryResponse,
    GetToolDependentAgentsResponseModel,
    GetToolDependentAgentsResponseModelAgentsItem,
    GetToolDependentAgentsResponseModelAgentsItem_Available,
    GetToolDependentAgentsResponseModelAgentsItem_Unknown,
    GetVoicesResponse,
    GetVoicesV2Response,
    GetWorkspaceSecretsResponseModel,
    HistoryAlignmentResponseModel,
    HistoryAlignmentsResponseModel,
    HistoryItemResponse,
    HtmlExportOptions,
    HttpValidationError,
    ImageAvatar,
    InboundSipTrunkConfigRequestModel,
    InitialiseContext,
    InitializeConnection,
    InitializeConnectionMulti,
    IntegrationType,
    InvoiceResponse,
    KeepContextAlive,
    KnowledgeBaseDocumentChunkResponseModel,
    KnowledgeBaseDocumentMetadataResponseModel,
    KnowledgeBaseDocumentType,
    KnowledgeBaseLocator,
    LanguageAddedResponse,
    LanguageDetectionToolConfig,
    LanguageDetectionToolResultModel,
    LanguagePresetInput,
    LanguagePresetOutput,
    LanguagePresetTranslation,
    LanguageResponse,
    LibraryVoiceResponse,
    LibraryVoiceResponseModelCategory,
    ListMcpToolsResponseModel,
    LiteralJsonSchemaProperty,
    LiteralJsonSchemaPropertyConstantValue,
    LiteralJsonSchemaPropertyType,
    Llm,
    LlmCategoryUsage,
    LlmInputOutputTokensUsage,
    LlmTokensCategoryUsage,
    LlmUsageCalculatorLlmResponseModel,
    LlmUsageCalculatorResponseModel,
    LlmUsageInput,
    LlmUsageOutput,
    ManualVerificationFileResponse,
    ManualVerificationResponse,
    McpApprovalPolicy,
    McpServerConfigInput,
    McpServerConfigInputRequestHeadersValue,
    McpServerConfigInputSecretToken,
    McpServerConfigInputUrl,
    McpServerConfigOutput,
    McpServerConfigOutputRequestHeadersValue,
    McpServerConfigOutputSecretToken,
    McpServerConfigOutputUrl,
    McpServerMetadataResponseModel,
    McpServerResponseModel,
    McpServerResponseModelDependentAgentsItem,
    McpServerResponseModelDependentAgentsItem_Available,
    McpServerResponseModelDependentAgentsItem_Unknown,
    McpServerTransport,
    McpServersResponseModel,
    McpToolApprovalHash,
    McpToolApprovalPolicy,
    MetricRecord,
    MetricType,
    Model,
    ModelRatesResponseModel,
    ModelResponseModelConcurrencyGroup,
    ModelSettingsResponseModel,
    ModerationStatusResponseModel,
    ModerationStatusResponseModelSafetyStatus,
    ModerationStatusResponseModelWarningStatus,
    MultichannelSpeechToTextResponseModel,
    MusicPrompt,
    NormalizedAlignment,
    ObjectJsonSchemaPropertyInput,
    ObjectJsonSchemaPropertyInputPropertiesValue,
    ObjectJsonSchemaPropertyOutput,
    ObjectJsonSchemaPropertyOutputPropertiesValue,
    OrbAvatar,
    OutboundCallRecipient,
    OutboundCallRecipientResponseModel,
    OutboundSipTrunkConfigRequestModel,
    OutputFormat,
    PdfExportOptions,
    PhoneNumberAgentInfo,
    PhoneNumberTransfer,
    PhoneNumberTransferDestination,
    PhoneNumberTransferTransferDestination,
    PhoneNumberTransferTransferDestination_Phone,
    PhoneNumberTransferTransferDestination_SipUri,
    PlayDtmfResultErrorModel,
    PlayDtmfResultSuccessModel,
    PlayDtmfToolConfig,
    PodcastBulletinMode,
    PodcastBulletinModeData,
    PodcastConversationMode,
    PodcastConversationModeData,
    PodcastProjectResponseModel,
    PodcastTextSource,
    PodcastUrlSource,
    PostAgentAvatarResponseModel,
    PostWorkspaceSecretResponseModel,
    PrivacyConfig,
    ProjectCreationMetaResponseModel,
    ProjectCreationMetaResponseModelStatus,
    ProjectCreationMetaResponseModelType,
    ProjectExtendedResponse,
    ProjectExtendedResponseModelAccessLevel,
    ProjectExtendedResponseModelApplyTextNormalization,
    ProjectExtendedResponseModelFiction,
    ProjectExtendedResponseModelQualityPreset,
    ProjectExtendedResponseModelSourceType,
    ProjectExtendedResponseModelTargetAudience,
    ProjectResponse,
    ProjectResponseModelAccessLevel,
    ProjectResponseModelFiction,
    ProjectResponseModelSourceType,
    ProjectResponseModelTargetAudience,
    ProjectSnapshotExtendedResponseModel,
    ProjectSnapshotResponse,
    ProjectSnapshotsResponse,
    ProjectState,
    PromptAgent,
    PromptAgentApiModelInput,
    PromptAgentApiModelInputToolsItem,
    PromptAgentApiModelInputToolsItem_Client,
    PromptAgentApiModelInputToolsItem_Mcp,
    PromptAgentApiModelInputToolsItem_System,
    PromptAgentApiModelInputToolsItem_Webhook,
    PromptAgentApiModelOutput,
    PromptAgentApiModelOutputToolsItem,
    PromptAgentApiModelOutputToolsItem_Client,
    PromptAgentApiModelOutputToolsItem_Mcp,
    PromptAgentApiModelOutputToolsItem_System,
    PromptAgentApiModelOutputToolsItem_Webhook,
    PromptAgentApiModelOverride,
    PromptAgentApiModelOverrideConfig,
    PromptAgentDbModel,
    PromptEvaluationCriteria,
    PronunciationDictionaryAliasRuleRequestModel,
    PronunciationDictionaryLocator,
    PronunciationDictionaryLocatorResponseModel,
    PronunciationDictionaryPhonemeRuleRequestModel,
    PronunciationDictionaryRulesResponseModel,
    PronunciationDictionaryVersionLocator,
    PronunciationDictionaryVersionResponseModel,
    PronunciationDictionaryVersionResponseModelPermissionOnResource,
    PydanticPronunciationDictionaryVersionLocator,
    QueryParamsJsonSchema,
    RagChunkMetadata,
    RagConfig,
    RagDocumentIndexResponseModel,
    RagDocumentIndexUsage,
    RagDocumentIndexesResponseModel,
    RagIndexOverviewEmbeddingModelResponseModel,
    RagIndexOverviewResponseModel,
    RagIndexStatus,
    RagRetrievalInfo,
    ReaderResourceResponseModel,
    ReaderResourceResponseModelResourceType,
    RealtimeVoiceSettings,
    RecordingResponse,
    RemoveMemberFromGroupRequest,
    Render,
    RenderStatus,
    RenderType,
    RequestPvcManualVerificationResponseModel,
    ResourceAccessInfo,
    ResourceAccessInfoRole,
    ResourceMetadataResponseModel,
    ReviewStatus,
    SafetyCommonModel,
    SafetyEvaluation,
    SafetyResponseModel,
    SafetyRule,
    SaveVoicePreviewRequest,
    SecretDependencyType,
    SegmentCreateResponse,
    SegmentDeleteResponse,
    SegmentDubResponse,
    SegmentSubtitleFrame,
    SegmentTranscriptionResponse,
    SegmentTranslationResponse,
    SegmentUpdateResponse,
    SegmentedJsonExportOptions,
    SendText,
    SendTextMulti,
    ShareOptionResponseModel,
    ShareOptionResponseModelType,
    SimilarVoice,
    SimilarVoiceCategory,
    SimilarVoicesForSpeakerResponse,
    SipMediaEncryptionEnum,
    SipTrunkCredentialsRequestModel,
    SipTrunkOutboundCallResponse,
    SipTrunkTransportEnum,
    SipUriTransferDestination,
    SkipTurnToolConfig,
    SkipTurnToolResponseModel,
    SongSection,
    SpeakerAudioResponseModel,
    SpeakerResponseModel,
    SpeakerSegment,
    SpeakerSeparationResponseModel,
    SpeakerSeparationResponseModelStatus,
    SpeakerTrack,
    SpeakerUpdatedResponse,
    SpeechHistoryItemResponse,
    SpeechHistoryItemResponseModelSource,
    SpeechHistoryItemResponseModelVoiceCategory,
    SpeechToTextCharacterResponseModel,
    SpeechToTextChunkResponseModel,
    SpeechToTextWebhookResponseModel,
    SpeechToTextWordResponseModel,
    SpeechToTextWordResponseModelType,
    SrtExportOptions,
    StartPvcVoiceTrainingResponseModel,
    StartSpeakerSeparationResponseModel,
    StreamingAudioChunkWithTimestampsResponse,
    Subscription,
    SubscriptionExtrasResponseModel,
    SubscriptionResponse,
    SubscriptionResponseModelBillingPeriod,
    SubscriptionResponseModelCharacterRefreshPeriod,
    SubscriptionResponseModelCurrency,
    SubscriptionStatusType,
    SubscriptionUsageResponseModel,
    SupportedVoice,
    SystemToolConfigInput,
    SystemToolConfigInputParams,
    SystemToolConfigInputParams_EndCall,
    SystemToolConfigInputParams_LanguageDetection,
    SystemToolConfigInputParams_PlayKeypadTouchTone,
    SystemToolConfigInputParams_SkipTurn,
    SystemToolConfigInputParams_TransferToAgent,
    SystemToolConfigInputParams_TransferToNumber,
    SystemToolConfigInputParams_VoicemailDetection,
    SystemToolConfigOutput,
    SystemToolConfigOutputParams,
    SystemToolConfigOutputParams_EndCall,
    SystemToolConfigOutputParams_LanguageDetection,
    SystemToolConfigOutputParams_PlayKeypadTouchTone,
    SystemToolConfigOutputParams_SkipTurn,
    SystemToolConfigOutputParams_TransferToAgent,
    SystemToolConfigOutputParams_TransferToNumber,
    SystemToolConfigOutputParams_VoicemailDetection,
    TelephonyProvider,
    TextToSpeechApplyTextNormalizationEnum,
    TextToSpeechOutputFormatEnum,
    TextToSpeechStreamRequest,
    TokenResponseModel,
    Tool,
    ToolAnnotations,
    ToolMockConfig,
    ToolRequestModel,
    ToolRequestModelToolConfig,
    ToolRequestModelToolConfig_Client,
    ToolRequestModelToolConfig_Mcp,
    ToolRequestModelToolConfig_System,
    ToolRequestModelToolConfig_Webhook,
    ToolResponseModel,
    ToolResponseModelToolConfig,
    ToolResponseModelToolConfig_Client,
    ToolResponseModelToolConfig_Mcp,
    ToolResponseModelToolConfig_System,
    ToolResponseModelToolConfig_Webhook,
    ToolType,
    ToolUsageStatsResponseModel,
    ToolsResponseModel,
    TransferToAgentToolConfig,
    TransferToAgentToolResultErrorModel,
    TransferToAgentToolResultSuccessModel,
    TransferToNumberResultErrorModel,
    TransferToNumberResultSipSuccessModel,
    TransferToNumberResultTwilioSuccessModel,
    TransferToNumberToolConfigInput,
    TransferToNumberToolConfigOutput,
    TransferTypeEnum,
    TtsConversationalConfigInput,
    TtsConversationalConfigOutput,
    TtsConversationalConfigOverride,
    TtsConversationalConfigOverrideConfig,
    TtsConversationalModel,
    TtsModelFamily,
    TtsOptimizeStreamingLatency,
    TtsOutputFormat,
    TurnConfig,
    TurnMode,
    TwilioOutboundCallResponse,
    TxtExportOptions,
    UpdateAudioNativeProjectRequest,
    UpdateChapterRequest,
    UpdateProjectRequest,
    UpdatePronunciationDictionariesRequest,
    UpdateWorkspaceMemberResponseModel,
    UrlAvatar,
    UsageAggregationInterval,
    UsageCharactersResponseModel,
    User,
    UserFeedback,
    UserFeedbackScore,
    UtteranceResponseModel,
    ValidationError,
    ValidationErrorLocItem,
    VerificationAttemptResponse,
    VerifiedVoiceLanguageResponseModel,
    VerifyPvcVoiceCaptchaResponseModel,
    Voice,
    VoiceDesignPreviewResponse,
    VoiceGenerationParameterOptionResponse,
    VoiceGenerationParameterResponse,
    VoiceMailDetectionResultSuccessModel,
    VoicePreviewResponseModel,
    VoiceResponseModelCategory,
    VoiceResponseModelSafetyControl,
    VoiceSample,
    VoiceSamplePreviewResponseModel,
    VoiceSampleVisualWaveformResponseModel,
    VoiceSettings,
    VoiceSharingModerationCheckResponseModel,
    VoiceSharingResponse,
    VoiceSharingResponseModelCategory,
    VoiceSharingState,
    VoiceVerificationResponse,
    VoicemailDetectionToolConfig,
    WebhookAuthMethodType,
    WebhookToolApiSchemaConfigInput,
    WebhookToolApiSchemaConfigInputMethod,
    WebhookToolApiSchemaConfigInputRequestHeadersValue,
    WebhookToolApiSchemaConfigOutput,
    WebhookToolApiSchemaConfigOutputMethod,
    WebhookToolApiSchemaConfigOutputRequestHeadersValue,
    WebhookToolConfigInput,
    WebhookToolConfigOutput,
    WebhookUsageType,
    WebsocketTtsClientMessageMulti,
    WebsocketTtsServerMessageMulti,
    WidgetConfig,
    WidgetConfigInputAvatar,
    WidgetConfigInputAvatar_Image,
    WidgetConfigInputAvatar_Orb,
    WidgetConfigInputAvatar_Url,
    WidgetConfigOutputAvatar,
    WidgetConfigOutputAvatar_Image,
    WidgetConfigOutputAvatar_Orb,
    WidgetConfigOutputAvatar_Url,
    WidgetConfigResponse,
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
    WidgetExpandable,
    WidgetFeedbackMode,
    WidgetLanguagePreset,
    WidgetLanguagePresetResponse,
    WidgetPlacement,
    WidgetStyles,
    WidgetTextContents,
    WorkflowToolEdgeStepModel,
    WorkflowToolMaxIterationsExceededStepModel,
    WorkflowToolNestedToolsStepModelInput,
    WorkflowToolNestedToolsStepModelInputResultsItem,
    WorkflowToolNestedToolsStepModelOutput,
    WorkflowToolNestedToolsStepModelOutputResultsItem,
    WorkflowToolResponseModelInput,
    WorkflowToolResponseModelInputStepsItem,
    WorkflowToolResponseModelInputStepsItem_Edge,
    WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelInputStepsItem_NestedTools,
    WorkflowToolResponseModelOutput,
    WorkflowToolResponseModelOutputStepsItem,
    WorkflowToolResponseModelOutputStepsItem_Edge,
    WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelOutputStepsItem_NestedTools,
    WorkspaceApiKeyListResponseModel,
    WorkspaceApiKeyResponseModel,
    WorkspaceApiKeyResponseModelPermissionsItem,
    WorkspaceBatchCallsResponse,
    WorkspaceCreateApiKeyResponseModel,
    WorkspaceGroupByNameResponseModel,
    WorkspaceResourceType,
    WorkspaceServiceAccountListResponseModel,
    WorkspaceServiceAccountResponseModel,
    WorkspaceWebhookListResponseModel,
    WorkspaceWebhookResponseModel,
    WorkspaceWebhookUsageResponseModel,
)
from .errors import BadRequestError, ForbiddenError, NotFoundError, TooEarlyError, UnprocessableEntityError
from . import (
    audio_isolation,
    audio_native,
    conversational_ai,
    dubbing,
    forced_alignment,
    history,
    models,
    music,
    pronunciation_dictionaries,
    samples,
    service_accounts,
    speech_to_speech,
    speech_to_text,
    studio,
    text_to_dialogue,
    text_to_sound_effects,
    text_to_speech,
    text_to_voice,
    usage,
    user,
    v_1_text_to_speech_voice_id_multi_stream_input,
    v_1_text_to_speech_voice_id_stream_input,
    voices,
    webhooks,
    workspace,
)
from .audio_isolation import AudioIsolationConvertRequestFileFormat, AudioIsolationStreamRequestFileFormat
from .client import AsyncElevenLabs, ElevenLabs
from .dubbing import DubbingListRequestDubbingStatus, DubbingListRequestFilterByCreator
from .environment import ElevenLabsEnvironment
from .history import HistoryListRequestSource
from .music import (
    MusicComposeDetailedRequestOutputFormat,
    MusicComposeRequestOutputFormat,
    MusicStreamRequestOutputFormat,
)
from .play import play, save, stream
from .pronunciation_dictionaries import (
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
    PronunciationDictionariesCreateFromFileRequestWorkspaceAccess,
    PronunciationDictionariesListRequestSort,
)
from .speech_to_speech import (
    SpeechToSpeechConvertRequestFileFormat,
    SpeechToSpeechConvertRequestOutputFormat,
    SpeechToSpeechStreamRequestFileFormat,
    SpeechToSpeechStreamRequestOutputFormat,
)
from .speech_to_text import (
    SpeechToTextConvertRequestFileFormat,
    SpeechToTextConvertRequestTimestampsGranularity,
    SpeechToTextConvertRequestWebhookMetadata,
    SpeechToTextConvertResponse,
)
from .studio import (
    BodyCreatePodcastV1StudioPodcastsPostDurationScale,
    BodyCreatePodcastV1StudioPodcastsPostMode,
    BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
    BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
    BodyCreatePodcastV1StudioPodcastsPostQualityPreset,
    BodyCreatePodcastV1StudioPodcastsPostSource,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url,
)
from .text_to_dialogue import TextToDialogueConvertRequestOutputFormat, TextToDialogueStreamRequestOutputFormat
from .text_to_sound_effects import TextToSoundEffectsConvertRequestOutputFormat
from .text_to_speech import (
    BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization,
    BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization,
    BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization,
    BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization,
    TextToSpeechConvertRequestOutputFormat,
    TextToSpeechConvertWithTimestampsRequestOutputFormat,
    TextToSpeechStreamRequestOutputFormat,
    TextToSpeechStreamWithTimestampsRequestOutputFormat,
)
from .text_to_voice import (
    TextToVoiceCreatePreviewsRequestOutputFormat,
    TextToVoiceDesignRequestOutputFormat,
    VoiceDesignRequestModelModelId,
)
from .v_1_text_to_speech_voice_id_multi_stream_input import ReceiveMessageMulti, SendMessageMulti
from .v_1_text_to_speech_voice_id_stream_input import ReceiveMessage, SendMessage
from .version import __version__
from .voices import VoicesGetSharedRequestCategory

__all__ = [
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectRequest",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryResponseModelPermissionOnResource",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "AdditionalFormatResponseModel",
    "AdditionalFormats",
    "Age",
    "AgentCallLimits",
    "AgentConfig",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentSimulatedChatTestResponseModel",
    "AgentSummaryResponseModel",
    "AgentTestingSettings",
    "AgentTransfer",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "Alignment",
    "AllowlistItem",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AsyncElevenLabs",
    "AudioIsolationConvertRequestFileFormat",
    "AudioIsolationStreamRequestFileFormat",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioNativeProjectSettingsResponseModelStatus",
    "AudioOutput",
    "AudioOutputMulti",
    "AudioWithTimestampsResponse",
    "AuthConnectionLocator",
    "AuthSettings",
    "AuthorizationMethod",
    "BadRequestError",
    "BadRequestErrorBody",
    "BanReasonType",
    "BatchCallDetailedResponse",
    "BatchCallRecipientStatus",
    "BatchCallResponse",
    "BatchCallStatus",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostQualityPreset",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender",
    "BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization",
    "BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization",
    "BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization",
    "BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization",
    "BreakdownTypes",
    "BuiltInToolsInput",
    "BuiltInToolsOutput",
    "CaptionStyleCharacterAnimationModel",
    "CaptionStyleCharacterAnimationModelEnterType",
    "CaptionStyleCharacterAnimationModelExitType",
    "CaptionStyleHorizontalPlacementModel",
    "CaptionStyleHorizontalPlacementModelAlign",
    "CaptionStyleModel",
    "CaptionStyleModelTextAlign",
    "CaptionStyleModelTextStyle",
    "CaptionStyleModelTextWeight",
    "CaptionStyleSectionAnimationModel",
    "CaptionStyleSectionAnimationModelEnterType",
    "CaptionStyleSectionAnimationModelExitType",
    "CaptionStyleTemplateModel",
    "CaptionStyleVerticalPlacementModel",
    "CaptionStyleVerticalPlacementModelAlign",
    "CaptionStyleWordAnimationModel",
    "CaptionStyleWordAnimationModelEnterType",
    "CaptionStyleWordAnimationModelExitType",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockInputModelSubType",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "CharacterUsageResponse",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "CloseConnection",
    "CloseContext",
    "CloseSocket",
    "ConvAiDynamicVariable",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentsItem",
    "ConvAiStoredSecretDependenciesAgentsItem_Available",
    "ConvAiStoredSecretDependenciesAgentsItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiUserSecretDbModel",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationConfigOverride",
    "ConversationConfigOverrideConfig",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryBatchCallModel",
    "ConversationHistoryElevenAssistantCommonModel",
    "ConversationHistoryErrorCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryRagUsageCommonModel",
    "ConversationHistorySipTrunkingPhoneCallModel",
    "ConversationHistorySipTrunkingPhoneCallModelDirection",
    "ConversationHistoryTranscriptCommonModelInput",
    "ConversationHistoryTranscriptCommonModelInputRole",
    "ConversationHistoryTranscriptCommonModelInputSourceMedium",
    "ConversationHistoryTranscriptCommonModelInputToolResultsItem",
    "ConversationHistoryTranscriptCommonModelOutput",
    "ConversationHistoryTranscriptCommonModelOutputRole",
    "ConversationHistoryTranscriptCommonModelOutputSourceMedium",
    "ConversationHistoryTranscriptCommonModelOutputToolResultsItem",
    "ConversationHistoryTranscriptOtherToolsResultCommonModel",
    "ConversationHistoryTranscriptOtherToolsResultCommonModelType",
    "ConversationHistoryTranscriptSystemToolResultCommonModel",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess",
    "ConversationHistoryTranscriptToolCallClientDetails",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook",
    "ConversationHistoryTranscriptToolCallMcpDetails",
    "ConversationHistoryTranscriptToolCallWebhookDetails",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationHistoryTwilioPhoneCallModelDirection",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataInternal",
    "ConversationInitiationClientDataInternalDynamicVariablesValue",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestInputDynamicVariablesValue",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataRequestOutputDynamicVariablesValue",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationInitiationSource",
    "ConversationInitiationSourceInfo",
    "ConversationSignedUrlResponseModel",
    "ConversationSimulationSpecification",
    "ConversationSimulationSpecificationDynamicVariablesValue",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelDirection",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationTurnMetrics",
    "ConversationalConfig",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentResponseModel",
    "CreateAudioNativeProjectRequest",
    "CreatePhoneNumberResponseModel",
    "CreatePreviouslyGeneratedVoiceRequest",
    "CreatePronunciationDictionaryResponseModel",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateTranscriptRequest",
    "CreateTwilioPhoneNumberRequest",
    "CustomLlm",
    "CustomLlmRequestHeadersValue",
    "DashboardCallSuccessChartModel",
    "DashboardCriteriaChartModel",
    "DashboardDataCollectionChartModel",
    "DataCollectionResultCommonModel",
    "DeleteChapterRequest",
    "DeleteChapterResponseModel",
    "DeleteDubbingResponseModel",
    "DeleteHistoryItemResponse",
    "DeleteProjectRequest",
    "DeleteProjectResponseModel",
    "DeleteSampleResponse",
    "DeleteVoiceResponseModel",
    "DeleteVoiceSampleResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DeleteWorkspaceMemberResponseModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownToolIdentifier",
    "DialogueInput",
    "DialogueInputResponseModel",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DocxExportOptions",
    "DubbedSegment",
    "DubbingListRequestDubbingStatus",
    "DubbingListRequestFilterByCreator",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataPageResponseModel",
    "DubbingMetadataResponse",
    "DubbingRenderResponseModel",
    "DubbingResource",
    "DynamicVariableAssignment",
    "DynamicVariableUpdateCommonModel",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsRequest",
    "EditVoiceSettingsResponseModel",
    "ElevenLabs",
    "ElevenLabsEnvironment",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EndCallToolConfig",
    "EndCallToolResultModel",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExportOptions",
    "ExportOptions_Docx",
    "ExportOptions_Html",
    "ExportOptions_Pdf",
    "ExportOptions_SegmentedJson",
    "ExportOptions_Srt",
    "ExportOptions_Txt",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeatureStatusCommonModel",
    "FeaturesUsageCommonModel",
    "FeedbackItem",
    "FinalOutput",
    "FinalOutputMulti",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "FlushContext",
    "ForbiddenError",
    "ForcedAlignmentCharacterResponseModel",
    "ForcedAlignmentResponseModel",
    "ForcedAlignmentWordResponseModel",
    "Gender",
    "GenerateVoiceRequest",
    "GenerationConfig",
    "GetAgentEmbedResponseModel",
    "GetAgentKnowledgebaseSizeResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentResponseModelPhoneNumbersItem",
    "GetAgentResponseModelPhoneNumbersItem_SipTrunk",
    "GetAgentResponseModelPhoneNumbersItem_Twilio",
    "GetAgentsPageResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetChapterRequest",
    "GetChapterSnapshotsRequest",
    "GetChaptersRequest",
    "GetChaptersResponse",
    "GetConvAiDashboardSettingsResponseModel",
    "GetConvAiDashboardSettingsResponseModelChartsItem",
    "GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess",
    "GetConvAiDashboardSettingsResponseModelChartsItem_Criteria",
    "GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Text",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryTextResponseModel",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseTextResponseModel",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberInboundSipTrunkConfigResponseModel",
    "GetPhoneNumberOutboundSipTrunkConfigResponseModel",
    "GetPhoneNumberResponse",
    "GetPhoneNumberSipTrunkResponseModel",
    "GetPhoneNumberTwilioResponseModel",
    "GetProjectRequest",
    "GetProjectsRequest",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionariesResponse",
    "GetPronunciationDictionaryMetadataResponse",
    "GetPronunciationDictionaryMetadataResponseModelPermissionOnResource",
    "GetPronunciationDictionaryResponse",
    "GetSpeechHistoryResponse",
    "GetToolDependentAgentsResponseModel",
    "GetToolDependentAgentsResponseModelAgentsItem",
    "GetToolDependentAgentsResponseModelAgentsItem_Available",
    "GetToolDependentAgentsResponseModelAgentsItem_Unknown",
    "GetVoicesResponse",
    "GetVoicesV2Response",
    "GetWorkspaceSecretsResponseModel",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItemResponse",
    "HistoryListRequestSource",
    "HtmlExportOptions",
    "HttpValidationError",
    "ImageAvatar",
    "InboundSipTrunkConfigRequestModel",
    "InitialiseContext",
    "InitializeConnection",
    "InitializeConnectionMulti",
    "IntegrationType",
    "InvoiceResponse",
    "KeepContextAlive",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseDocumentType",
    "KnowledgeBaseLocator",
    "LanguageAddedResponse",
    "LanguageDetectionToolConfig",
    "LanguageDetectionToolResultModel",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "ListMcpToolsResponseModel",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "LlmCategoryUsage",
    "LlmInputOutputTokensUsage",
    "LlmTokensCategoryUsage",
    "LlmUsageCalculatorLlmResponseModel",
    "LlmUsageCalculatorResponseModel",
    "LlmUsageInput",
    "LlmUsageOutput",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "McpApprovalPolicy",
    "McpServerConfigInput",
    "McpServerConfigInputRequestHeadersValue",
    "McpServerConfigInputSecretToken",
    "McpServerConfigInputUrl",
    "McpServerConfigOutput",
    "McpServerConfigOutputRequestHeadersValue",
    "McpServerConfigOutputSecretToken",
    "McpServerConfigOutputUrl",
    "McpServerMetadataResponseModel",
    "McpServerResponseModel",
    "McpServerResponseModelDependentAgentsItem",
    "McpServerResponseModelDependentAgentsItem_Available",
    "McpServerResponseModelDependentAgentsItem_Unknown",
    "McpServerTransport",
    "McpServersResponseModel",
    "McpToolApprovalHash",
    "McpToolApprovalPolicy",
    "MetricRecord",
    "MetricType",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModelSettingsResponseModel",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "MultichannelSpeechToTextResponseModel",
    "MusicComposeDetailedRequestOutputFormat",
    "MusicComposeRequestOutputFormat",
    "MusicPrompt",
    "MusicStreamRequestOutputFormat",
    "NormalizedAlignment",
    "NotFoundError",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OrbAvatar",
    "OutboundCallRecipient",
    "OutboundCallRecipientResponseModel",
    "OutboundSipTrunkConfigRequestModel",
    "OutputFormat",
    "PdfExportOptions",
    "PhoneNumberAgentInfo",
    "PhoneNumberTransfer",
    "PhoneNumberTransferDestination",
    "PhoneNumberTransferTransferDestination",
    "PhoneNumberTransferTransferDestination_Phone",
    "PhoneNumberTransferTransferDestination_SipUri",
    "PlayDtmfResultErrorModel",
    "PlayDtmfResultSuccessModel",
    "PlayDtmfToolConfig",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PostWorkspaceSecretResponseModel",
    "PrivacyConfig",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponse",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgent",
    "PromptAgentApiModelInput",
    "PromptAgentApiModelInputToolsItem",
    "PromptAgentApiModelInputToolsItem_Client",
    "PromptAgentApiModelInputToolsItem_Mcp",
    "PromptAgentApiModelInputToolsItem_System",
    "PromptAgentApiModelInputToolsItem_Webhook",
    "PromptAgentApiModelOutput",
    "PromptAgentApiModelOutputToolsItem",
    "PromptAgentApiModelOutputToolsItem_Client",
    "PromptAgentApiModelOutputToolsItem_Mcp",
    "PromptAgentApiModelOutputToolsItem_System",
    "PromptAgentApiModelOutputToolsItem_Webhook",
    "PromptAgentApiModelOverride",
    "PromptAgentApiModelOverrideConfig",
    "PromptAgentDbModel",
    "PromptEvaluationCriteria",
    "PronunciationDictionariesCreateFromFileRequestWorkspaceAccess",
    "PronunciationDictionariesListRequestSort",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryLocator",
    "PronunciationDictionaryLocatorResponseModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryRulesResponseModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PronunciationDictionaryVersionResponseModelPermissionOnResource",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "RagChunkMetadata",
    "RagConfig",
    "RagDocumentIndexResponseModel",
    "RagDocumentIndexUsage",
    "RagDocumentIndexesResponseModel",
    "RagIndexOverviewEmbeddingModelResponseModel",
    "RagIndexOverviewResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeVoiceSettings",
    "ReceiveMessage",
    "ReceiveMessageMulti",
    "RecordingResponse",
    "RemoveMemberFromGroupRequest",
    "Render",
    "RenderStatus",
    "RenderType",
    "RequestPvcManualVerificationResponseModel",
    "ResourceAccessInfo",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ReviewStatus",
    "SafetyCommonModel",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SaveVoicePreviewRequest",
    "SecretDependencyType",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentSubtitleFrame",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SegmentedJsonExportOptions",
    "SendMessage",
    "SendMessageMulti",
    "SendText",
    "SendTextMulti",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SimilarVoice",
    "SimilarVoiceCategory",
    "SimilarVoicesForSpeakerResponse",
    "SipMediaEncryptionEnum",
    "SipTrunkCredentialsRequestModel",
    "SipTrunkOutboundCallResponse",
    "SipTrunkTransportEnum",
    "SipUriTransferDestination",
    "SkipTurnToolConfig",
    "SkipTurnToolResponseModel",
    "SongSection",
    "SpeakerAudioResponseModel",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeakerUpdatedResponse",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToSpeechConvertRequestFileFormat",
    "SpeechToSpeechConvertRequestOutputFormat",
    "SpeechToSpeechStreamRequestFileFormat",
    "SpeechToSpeechStreamRequestOutputFormat",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextConvertRequestFileFormat",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextConvertRequestWebhookMetadata",
    "SpeechToTextConvertResponse",
    "SpeechToTextWebhookResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "SrtExportOptions",
    "StartPvcVoiceTrainingResponseModel",
    "StartSpeakerSeparationResponseModel",
    "StreamingAudioChunkWithTimestampsResponse",
    "Subscription",
    "SubscriptionExtrasResponseModel",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatusType",
    "SubscriptionUsageResponseModel",
    "SupportedVoice",
    "SystemToolConfigInput",
    "SystemToolConfigInputParams",
    "SystemToolConfigInputParams_EndCall",
    "SystemToolConfigInputParams_LanguageDetection",
    "SystemToolConfigInputParams_PlayKeypadTouchTone",
    "SystemToolConfigInputParams_SkipTurn",
    "SystemToolConfigInputParams_TransferToAgent",
    "SystemToolConfigInputParams_TransferToNumber",
    "SystemToolConfigInputParams_VoicemailDetection",
    "SystemToolConfigOutput",
    "SystemToolConfigOutputParams",
    "SystemToolConfigOutputParams_EndCall",
    "SystemToolConfigOutputParams_LanguageDetection",
    "SystemToolConfigOutputParams_PlayKeypadTouchTone",
    "SystemToolConfigOutputParams_SkipTurn",
    "SystemToolConfigOutputParams_TransferToAgent",
    "SystemToolConfigOutputParams_TransferToNumber",
    "SystemToolConfigOutputParams_VoicemailDetection",
    "TelephonyProvider",
    "TextToDialogueConvertRequestOutputFormat",
    "TextToDialogueStreamRequestOutputFormat",
    "TextToSoundEffectsConvertRequestOutputFormat",
    "TextToSpeechApplyTextNormalizationEnum",
    "TextToSpeechConvertRequestOutputFormat",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat",
    "TextToSpeechOutputFormatEnum",
    "TextToSpeechStreamRequest",
    "TextToSpeechStreamRequestOutputFormat",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat",
    "TextToVoiceCreatePreviewsRequestOutputFormat",
    "TextToVoiceDesignRequestOutputFormat",
    "TokenResponseModel",
    "TooEarlyError",
    "Tool",
    "ToolAnnotations",
    "ToolMockConfig",
    "ToolRequestModel",
    "ToolRequestModelToolConfig",
    "ToolRequestModelToolConfig_Client",
    "ToolRequestModelToolConfig_Mcp",
    "ToolRequestModelToolConfig_System",
    "ToolRequestModelToolConfig_Webhook",
    "ToolResponseModel",
    "ToolResponseModelToolConfig",
    "ToolResponseModelToolConfig_Client",
    "ToolResponseModelToolConfig_Mcp",
    "ToolResponseModelToolConfig_System",
    "ToolResponseModelToolConfig_Webhook",
    "ToolType",
    "ToolUsageStatsResponseModel",
    "ToolsResponseModel",
    "TransferToAgentToolConfig",
    "TransferToAgentToolResultErrorModel",
    "TransferToAgentToolResultSuccessModel",
    "TransferToNumberResultErrorModel",
    "TransferToNumberResultSipSuccessModel",
    "TransferToNumberResultTwilioSuccessModel",
    "TransferToNumberToolConfigInput",
    "TransferToNumberToolConfigOutput",
    "TransferTypeEnum",
    "TtsConversationalConfigInput",
    "TtsConversationalConfigOutput",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsModelFamily",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "TwilioOutboundCallResponse",
    "TxtExportOptions",
    "UnprocessableEntityError",
    "UpdateAudioNativeProjectRequest",
    "UpdateChapterRequest",
    "UpdateProjectRequest",
    "UpdatePronunciationDictionariesRequest",
    "UpdateWorkspaceMemberResponseModel",
    "UrlAvatar",
    "UsageAggregationInterval",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "UtteranceResponseModel",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "VerifyPvcVoiceCaptchaResponseModel",
    "Voice",
    "VoiceDesignPreviewResponse",
    "VoiceDesignRequestModelModelId",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoiceMailDetectionResultSuccessModel",
    "VoicePreviewResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSamplePreviewResponseModel",
    "VoiceSampleVisualWaveformResponseModel",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "VoicemailDetectionToolConfig",
    "VoicesGetSharedRequestCategory",
    "WebhookAuthMethodType",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WebhookUsageType",
    "WebsocketTtsClientMessageMulti",
    "WebsocketTtsServerMessageMulti",
    "WidgetConfig",
    "WidgetConfigInputAvatar",
    "WidgetConfigInputAvatar_Image",
    "WidgetConfigInputAvatar_Orb",
    "WidgetConfigInputAvatar_Url",
    "WidgetConfigOutputAvatar",
    "WidgetConfigOutputAvatar_Image",
    "WidgetConfigOutputAvatar_Orb",
    "WidgetConfigOutputAvatar_Url",
    "WidgetConfigResponse",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WidgetLanguagePreset",
    "WidgetLanguagePresetResponse",
    "WidgetPlacement",
    "WidgetStyles",
    "WidgetTextContents",
    "WorkflowToolEdgeStepModel",
    "WorkflowToolMaxIterationsExceededStepModel",
    "WorkflowToolNestedToolsStepModelInput",
    "WorkflowToolNestedToolsStepModelInputResultsItem",
    "WorkflowToolNestedToolsStepModelOutput",
    "WorkflowToolNestedToolsStepModelOutputResultsItem",
    "WorkflowToolResponseModelInput",
    "WorkflowToolResponseModelInputStepsItem",
    "WorkflowToolResponseModelInputStepsItem_Edge",
    "WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelInputStepsItem_NestedTools",
    "WorkflowToolResponseModelOutput",
    "WorkflowToolResponseModelOutputStepsItem",
    "WorkflowToolResponseModelOutputStepsItem_Edge",
    "WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelOutputStepsItem_NestedTools",
    "WorkspaceApiKeyListResponseModel",
    "WorkspaceApiKeyResponseModel",
    "WorkspaceApiKeyResponseModelPermissionsItem",
    "WorkspaceBatchCallsResponse",
    "WorkspaceCreateApiKeyResponseModel",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceResourceType",
    "WorkspaceServiceAccountListResponseModel",
    "WorkspaceServiceAccountResponseModel",
    "WorkspaceWebhookListResponseModel",
    "WorkspaceWebhookResponseModel",
    "WorkspaceWebhookUsageResponseModel",
    "__version__",
    "audio_isolation",
    "audio_native",
    "conversational_ai",
    "dubbing",
    "forced_alignment",
    "history",
    "models",
    "music",
    "play",
    "pronunciation_dictionaries",
    "samples",
    "save",
    "service_accounts",
    "speech_to_speech",
    "speech_to_text",
    "stream",
    "studio",
    "text_to_dialogue",
    "text_to_sound_effects",
    "text_to_speech",
    "text_to_voice",
    "usage",
    "user",
    "v_1_text_to_speech_voice_id_multi_stream_input",
    "v_1_text_to_speech_voice_id_stream_input",
    "voices",
    "webhooks",
    "workspace",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import jsonable_encoder
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ...errors.forbidden_error import ForbiddenError
from ...errors.not_found_error import NotFoundError
from ...errors.too_early_error import TooEarlyError
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.http_validation_error import HttpValidationError
from .types.transcript_get_transcript_for_dub_request_format_type import TranscriptGetTranscriptForDubRequestFormatType


class RawTranscriptClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_transcript_for_dub(
        self,
        dubbing_id: str,
        language_code: str,
        *,
        format_type: typing.Optional[TranscriptGetTranscriptForDubRequestFormatType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[str]:
        """
        Returns transcript for the dub as an SRT or WEBVTT file.

        Parameters
        ----------
        dubbing_id : str
            ID of the dubbing project.

        language_code : str
            ID of the language.

        format_type : typing.Optional[TranscriptGetTranscriptForDubRequestFormatType]
            Format to use for the subtitle file, either 'srt' or 'webvtt'

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[str]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/dubbing/{jsonable_encoder(dubbing_id)}/transcript/{jsonable_encoder(language_code)}",
            method="GET",
            params={
                "format_type": format_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=_response.text)  # type: ignore
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 425:
                raise TooEarlyError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTranscriptClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_transcript_for_dub(
        self,
        dubbing_id: str,
        language_code: str,
        *,
        format_type: typing.Optional[TranscriptGetTranscriptForDubRequestFormatType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[str]:
        """
        Returns transcript for the dub as an SRT or WEBVTT file.

        Parameters
        ----------
        dubbing_id : str
            ID of the dubbing project.

        language_code : str
            ID of the language.

        format_type : typing.Optional[TranscriptGetTranscriptForDubRequestFormatType]
            Format to use for the subtitle file, either 'srt' or 'webvtt'

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[str]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/dubbing/{jsonable_encoder(dubbing_id)}/transcript/{jsonable_encoder(language_code)}",
            method="GET",
            params={
                "format_type": format_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=_response.text)  # type: ignore
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 425:
                raise TooEarlyError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .text_to_voice_create_previews_request_output_format import TextToVoiceCreatePreviewsRequestOutputFormat
from .text_to_voice_design_request_output_format import TextToVoiceDesignRequestOutputFormat
from .voice_design_request_model_model_id import VoiceDesignRequestModelModelId

__all__ = [
    "TextToVoiceCreatePreviewsRequestOutputFormat",
    "TextToVoiceDesignRequestOutputFormat",
    "VoiceDesignRequestModelModelId",
]



# This file was auto-generated by Fern from our API Definition.

import typing

RagIndexStatus = typing.Union[
    typing.Literal["created", "processing", "failed", "succeeded", "rag_limit_exceeded", "document_too_small"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from . import settings
from .settings import (
    PatchConvAiDashboardSettingsRequestChartsItem,
    PatchConvAiDashboardSettingsRequestChartsItem_CallSuccess,
    PatchConvAiDashboardSettingsRequestChartsItem_Criteria,
    PatchConvAiDashboardSettingsRequestChartsItem_DataCollection,
)

__all__ = [
    "PatchConvAiDashboardSettingsRequestChartsItem",
    "PatchConvAiDashboardSettingsRequestChartsItem_CallSuccess",
    "PatchConvAiDashboardSettingsRequestChartsItem_Criteria",
    "PatchConvAiDashboardSettingsRequestChartsItem_DataCollection",
    "settings",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .audio_isolation_convert_request_file_format import AudioIsolationConvertRequestFileFormat
from .audio_isolation_stream_request_file_format import AudioIsolationStreamRequestFileFormat

__all__ = ["AudioIsolationConvertRequestFileFormat", "AudioIsolationStreamRequestFileFormat"]



# This file was auto-generated by Fern from our API Definition.

import typing

from .body_edit_service_account_api_key_v_1_service_accounts_service_account_user_id_api_keys_api_key_id_patch_permissions_item import (
    BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchPermissionsItem,
)

BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchPermissions = typing.Union[
    typing.List[BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchPermissionsItem],
    typing.Literal["all"],
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import AudioIsolationConvertRequestFileFormat, AudioIsolationStreamRequestFileFormat

__all__ = ["AudioIsolationConvertRequestFileFormat", "AudioIsolationStreamRequestFileFormat"]



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawDashboardClient, RawDashboardClient
from .settings.client import AsyncSettingsClient, SettingsClient


class DashboardClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawDashboardClient(client_wrapper=client_wrapper)
        self.settings = SettingsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawDashboardClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawDashboardClient
        """
        return self._raw_client


class AsyncDashboardClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawDashboardClient(client_wrapper=client_wrapper)
        self.settings = AsyncSettingsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawDashboardClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawDashboardClient
        """
        return self._raw_client



# This file was auto-generated by Fern from our API Definition.

import typing

ConversationHistorySipTrunkingPhoneCallModelDirection = typing.Union[typing.Literal["inbound", "outbound"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    TextToVoiceCreatePreviewsRequestOutputFormat,
    TextToVoiceDesignRequestOutputFormat,
    VoiceDesignRequestModelModelId,
)
from . import preview

__all__ = [
    "TextToVoiceCreatePreviewsRequestOutputFormat",
    "TextToVoiceDesignRequestOutputFormat",
    "VoiceDesignRequestModelModelId",
    "preview",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CreatePreviouslyGeneratedVoiceRequest(UncheckedBaseModel):
    voice_name: str = pydantic.Field()
    """
    Name to use for the created voice.
    """

    voice_description: str = pydantic.Field()
    """
    Description to use for the created voice.
    """

    generated_voice_id: str = pydantic.Field()
    """
    The generated_voice_id to create, call POST /v1/text-to-voice/create-previews and fetch the generated_voice_id from the response header if don't have one yet.
    """

    played_not_selected_voice_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of voice ids that the user has played but not selected. Used for RLHF.
    """

    labels: typing.Optional[typing.Dict[str, typing.Optional[str]]] = pydantic.Field(default=None)
    """
    Optional, metadata to add to the created voice. Defaults to None.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .body_share_workspace_resource_v_1_workspace_resources_resource_id_share_post_role import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
)

__all__ = ["BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
    PronunciationDictionariesCreateFromFileRequestWorkspaceAccess,
    PronunciationDictionariesListRequestSort,
)
from . import rules
from .rules import PronunciationDictionaryRule, PronunciationDictionaryRule_Alias, PronunciationDictionaryRule_Phoneme

__all__ = [
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "PronunciationDictionariesCreateFromFileRequestWorkspaceAccess",
    "PronunciationDictionariesListRequestSort",
    "PronunciationDictionaryRule",
    "PronunciationDictionaryRule_Alias",
    "PronunciationDictionaryRule_Phoneme",
    "rules",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.resource_metadata_response_model import ResourceMetadataResponseModel
from ...types.workspace_resource_type import WorkspaceResourceType
from .raw_client import AsyncRawResourcesClient, RawResourcesClient
from .types.body_share_workspace_resource_v_1_workspace_resources_resource_id_share_post_role import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
)

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ResourcesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawResourcesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawResourcesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawResourcesClient
        """
        return self._raw_client

    def get(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResourceMetadataResponseModel:
        """
        Gets the metadata of a resource by ID.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResourceMetadataResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.resources.get(
            resource_id="resource_id",
            resource_type="voice",
        )
        """
        _response = self._raw_client.get(resource_id, resource_type=resource_type, request_options=request_options)
        return _response.data

    def share(
        self,
        resource_id: str,
        *,
        role: BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Grants a role on a workspace resource to a user or a group. It overrides any existing role this user/service account/group/workspace api key has on the resource. To target a user or service account, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. The resource will be shared with the service account associated with the api key. You must have admin access to the resource to share it.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        role : BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
            Role to update the target principal with.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user or service account.

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.resources.share(
            resource_id="resource_id",
            role="admin",
            resource_type="voice",
        )
        """
        _response = self._raw_client.share(
            resource_id,
            role=role,
            resource_type=resource_type,
            user_email=user_email,
            group_id=group_id,
            workspace_api_key_id=workspace_api_key_id,
            request_options=request_options,
        )
        return _response.data

    def unshare(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Removes any existing role on a workspace resource from a user, service account, group or workspace api key. To target a user or service account, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. The resource will be unshared from the service account associated with the api key. You must have admin access to the resource to unshare it. You cannot remove permissions from the user who created the resource.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user or service account.

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.workspace.resources.unshare(
            resource_id="resource_id",
            resource_type="voice",
        )
        """
        _response = self._raw_client.unshare(
            resource_id,
            resource_type=resource_type,
            user_email=user_email,
            group_id=group_id,
            workspace_api_key_id=workspace_api_key_id,
            request_options=request_options,
        )
        return _response.data


class AsyncResourcesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawResourcesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawResourcesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawResourcesClient
        """
        return self._raw_client

    async def get(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResourceMetadataResponseModel:
        """
        Gets the metadata of a resource by ID.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResourceMetadataResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.resources.get(
                resource_id="resource_id",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            resource_id, resource_type=resource_type, request_options=request_options
        )
        return _response.data

    async def share(
        self,
        resource_id: str,
        *,
        role: BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Grants a role on a workspace resource to a user or a group. It overrides any existing role this user/service account/group/workspace api key has on the resource. To target a user or service account, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. The resource will be shared with the service account associated with the api key. You must have admin access to the resource to share it.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        role : BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
            Role to update the target principal with.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user or service account.

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.resources.share(
                resource_id="resource_id",
                role="admin",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.share(
            resource_id,
            role=role,
            resource_type=resource_type,
            user_email=user_email,
            group_id=group_id,
            workspace_api_key_id=workspace_api_key_id,
            request_options=request_options,
        )
        return _response.data

    async def unshare(
        self,
        resource_id: str,
        *,
        resource_type: WorkspaceResourceType,
        user_email: typing.Optional[str] = OMIT,
        group_id: typing.Optional[str] = OMIT,
        workspace_api_key_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Optional[typing.Any]:
        """
        Removes any existing role on a workspace resource from a user, service account, group or workspace api key. To target a user or service account, pass only the user email. The user must be in your workspace. To target a group, pass only the group id. To target a workspace api key, pass the api key id. The resource will be unshared from the service account associated with the api key. You must have admin access to the resource to unshare it. You cannot remove permissions from the user who created the resource.

        Parameters
        ----------
        resource_id : str
            The ID of the target resource.

        resource_type : WorkspaceResourceType
            Resource type of the target resource.

        user_email : typing.Optional[str]
            The email of the user or service account.

        group_id : typing.Optional[str]
            The ID of the target group. To target the permissions principals have by default on this resource, use the value 'default'.

        workspace_api_key_id : typing.Optional[str]
            The ID of the target workspace API key. This isn't the same as the key itself that would you pass in the header for authentication. Workspace admins can find this in the workspace settings UI.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workspace.resources.unshare(
                resource_id="resource_id",
                resource_type="voice",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.unshare(
            resource_id,
            resource_type=resource_type,
            user_email=user_email,
            group_id=group_id,
            workspace_api_key_id=workspace_api_key_id,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.conversation_signed_url_response_model import ConversationSignedUrlResponseModel
from ...types.evaluation_success_result import EvaluationSuccessResult
from ...types.get_conversation_response_model import GetConversationResponseModel
from ...types.get_conversations_page_response_model import GetConversationsPageResponseModel
from ...types.token_response_model import TokenResponseModel
from .audio.client import AsyncAudioClient, AudioClient
from .feedback.client import AsyncFeedbackClient, FeedbackClient
from .raw_client import AsyncRawConversationsClient, RawConversationsClient
from .types.conversations_list_request_summary_mode import ConversationsListRequestSummaryMode


class ConversationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawConversationsClient(client_wrapper=client_wrapper)
        self.audio = AudioClient(client_wrapper=client_wrapper)

        self.feedback = FeedbackClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawConversationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawConversationsClient
        """
        return self._raw_client

    def get_signed_url(
        self, *, agent_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ConversationSignedUrlResponseModel:
        """
        Get a signed url to start a conversation with an agent with an agent that requires authorization

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConversationSignedUrlResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get_signed_url(
            agent_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.get_signed_url(agent_id=agent_id, request_options=request_options)
        return _response.data

    def get_webrtc_token(
        self,
        *,
        agent_id: str,
        participant_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TokenResponseModel:
        """
        Get a WebRTC session token for real-time communication.

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        participant_name : typing.Optional[str]
            Optional custom participant name. If not provided, user ID will be used

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TokenResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get_webrtc_token(
            agent_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.get_webrtc_token(
            agent_id=agent_id, participant_name=participant_name, request_options=request_options
        )
        return _response.data

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        agent_id: typing.Optional[str] = None,
        call_successful: typing.Optional[EvaluationSuccessResult] = None,
        call_start_before_unix: typing.Optional[int] = None,
        call_start_after_unix: typing.Optional[int] = None,
        user_id: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        summary_mode: typing.Optional[ConversationsListRequestSummaryMode] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetConversationsPageResponseModel:
        """
        Get all conversations of agents that user owns. With option to restrict to a specific agent.

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        agent_id : typing.Optional[str]
            The id of the agent you're taking the action on.

        call_successful : typing.Optional[EvaluationSuccessResult]
            The result of the success evaluation

        call_start_before_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations up to this start date.

        call_start_after_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations after to this start date.

        user_id : typing.Optional[str]
            Filter conversations by the user ID who initiated them.

        page_size : typing.Optional[int]
            How many conversations to return at maximum. Can not exceed 100, defaults to 30.

        summary_mode : typing.Optional[ConversationsListRequestSummaryMode]
            Whether to include transcript summaries in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationsPageResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.list()
        """
        _response = self._raw_client.list(
            cursor=cursor,
            agent_id=agent_id,
            call_successful=call_successful,
            call_start_before_unix=call_start_before_unix,
            call_start_after_unix=call_start_after_unix,
            user_id=user_id,
            page_size=page_size,
            summary_mode=summary_mode,
            request_options=request_options,
        )
        return _response.data

    def get(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetConversationResponseModel:
        """
        Get the details of a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get(
            conversation_id="123",
        )
        """
        _response = self._raw_client.get(conversation_id, request_options=request_options)
        return _response.data

    def delete(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Delete a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.delete(
            conversation_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.delete(conversation_id, request_options=request_options)
        return _response.data


class AsyncConversationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawConversationsClient(client_wrapper=client_wrapper)
        self.audio = AsyncAudioClient(client_wrapper=client_wrapper)

        self.feedback = AsyncFeedbackClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawConversationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawConversationsClient
        """
        return self._raw_client

    async def get_signed_url(
        self, *, agent_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ConversationSignedUrlResponseModel:
        """
        Get a signed url to start a conversation with an agent with an agent that requires authorization

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConversationSignedUrlResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get_signed_url(
                agent_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_signed_url(agent_id=agent_id, request_options=request_options)
        return _response.data

    async def get_webrtc_token(
        self,
        *,
        agent_id: str,
        participant_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TokenResponseModel:
        """
        Get a WebRTC session token for real-time communication.

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        participant_name : typing.Optional[str]
            Optional custom participant name. If not provided, user ID will be used

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TokenResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get_webrtc_token(
                agent_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_webrtc_token(
            agent_id=agent_id, participant_name=participant_name, request_options=request_options
        )
        return _response.data

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        agent_id: typing.Optional[str] = None,
        call_successful: typing.Optional[EvaluationSuccessResult] = None,
        call_start_before_unix: typing.Optional[int] = None,
        call_start_after_unix: typing.Optional[int] = None,
        user_id: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        summary_mode: typing.Optional[ConversationsListRequestSummaryMode] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetConversationsPageResponseModel:
        """
        Get all conversations of agents that user owns. With option to restrict to a specific agent.

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        agent_id : typing.Optional[str]
            The id of the agent you're taking the action on.

        call_successful : typing.Optional[EvaluationSuccessResult]
            The result of the success evaluation

        call_start_before_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations up to this start date.

        call_start_after_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations after to this start date.

        user_id : typing.Optional[str]
            Filter conversations by the user ID who initiated them.

        page_size : typing.Optional[int]
            How many conversations to return at maximum. Can not exceed 100, defaults to 30.

        summary_mode : typing.Optional[ConversationsListRequestSummaryMode]
            Whether to include transcript summaries in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationsPageResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            cursor=cursor,
            agent_id=agent_id,
            call_successful=call_successful,
            call_start_before_unix=call_start_before_unix,
            call_start_after_unix=call_start_after_unix,
            user_id=user_id,
            page_size=page_size,
            summary_mode=summary_mode,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetConversationResponseModel:
        """
        Get the details of a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get(
                conversation_id="123",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(conversation_id, request_options=request_options)
        return _response.data

    async def delete(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Delete a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.delete(
                conversation_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(conversation_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from .....core.pydantic_utilities import IS_PYDANTIC_V2
from .....core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .....types.document_usage_mode_enum import DocumentUsageModeEnum
from .....types.knowledge_base_document_metadata_response_model import KnowledgeBaseDocumentMetadataResponseModel
from .....types.resource_access_info import ResourceAccessInfo


class DocumentsGetResponse_Url(UncheckedBaseModel):
    type: typing.Literal["url"] = "url"
    id: str
    name: str
    metadata: KnowledgeBaseDocumentMetadataResponseModel
    supported_usages: typing.List[DocumentUsageModeEnum]
    access_info: ResourceAccessInfo
    extracted_inner_html: str
    url: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class DocumentsGetResponse_File(UncheckedBaseModel):
    type: typing.Literal["file"] = "file"
    id: str
    name: str
    metadata: KnowledgeBaseDocumentMetadataResponseModel
    supported_usages: typing.List[DocumentUsageModeEnum]
    access_info: ResourceAccessInfo
    extracted_inner_html: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class DocumentsGetResponse_Text(UncheckedBaseModel):
    type: typing.Literal["text"] = "text"
    id: str
    name: str
    metadata: KnowledgeBaseDocumentMetadataResponseModel
    supported_usages: typing.List[DocumentUsageModeEnum]
    access_info: ResourceAccessInfo
    extracted_inner_html: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


DocumentsGetResponse = typing_extensions.Annotated[
    typing.Union[DocumentsGetResponse_Url, DocumentsGetResponse_File, DocumentsGetResponse_Text],
    UnionMetadata(discriminant="type"),
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .body_create_service_account_api_key_v_1_service_accounts_service_account_user_id_api_keys_post_permissions_item import (
    BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissionsItem,
)

BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissions = typing.Union[
    typing.List[BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissionsItem],
    typing.Literal["all"],
]



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .audio_isolation.client import AsyncAudioIsolationClient, AudioIsolationClient
from .audio_native.client import AsyncAudioNativeClient, AudioNativeClient
from .conversational_ai.client import AsyncConversationalAiClient, ConversationalAiClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .dubbing.client import AsyncDubbingClient, DubbingClient
from .environment import ElevenLabsEnvironment
from .forced_alignment.client import AsyncForcedAlignmentClient, ForcedAlignmentClient
from .history.client import AsyncHistoryClient, HistoryClient
from .models.client import AsyncModelsClient, ModelsClient
from .music.client import AsyncMusicClient, MusicClient
from .pronunciation_dictionaries.client import AsyncPronunciationDictionariesClient, PronunciationDictionariesClient
from .raw_base_client import AsyncRawBaseElevenLabs, RawBaseElevenLabs
from .samples.client import AsyncSamplesClient, SamplesClient
from .service_accounts.client import AsyncServiceAccountsClient, ServiceAccountsClient
from .speech_to_speech.client import AsyncSpeechToSpeechClient, SpeechToSpeechClient
from .speech_to_text.client import AsyncSpeechToTextClient, SpeechToTextClient
from .studio.client import AsyncStudioClient, StudioClient
from .text_to_dialogue.client import AsyncTextToDialogueClient, TextToDialogueClient
from .text_to_sound_effects.client import AsyncTextToSoundEffectsClient, TextToSoundEffectsClient
from .text_to_speech.client import AsyncTextToSpeechClient, TextToSpeechClient
from .text_to_voice.client import AsyncTextToVoiceClient, TextToVoiceClient
from .usage.client import AsyncUsageClient, UsageClient
from .user.client import AsyncUserClient, UserClient
from .voices.client import AsyncVoicesClient, VoicesClient
from .webhooks.client import AsyncWebhooksClient, WebhooksClient
from .workspace.client import AsyncWorkspaceClient, WorkspaceClient


class BaseElevenLabs:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ElevenLabsEnvironment
        The environment to use for requests from the client. from .environment import ElevenLabsEnvironment



        Defaults to ElevenLabsEnvironment.PRODUCTION



    api_key : typing.Optional[str]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 240 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from elevenlabs import ElevenLabs

    client = ElevenLabs(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ElevenLabsEnvironment = ElevenLabsEnvironment.PRODUCTION,
        api_key: typing.Optional[str] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 240 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = RawBaseElevenLabs(client_wrapper=self._client_wrapper)
        self.history = HistoryClient(client_wrapper=self._client_wrapper)
        self.text_to_sound_effects = TextToSoundEffectsClient(client_wrapper=self._client_wrapper)
        self.audio_isolation = AudioIsolationClient(client_wrapper=self._client_wrapper)
        self.samples = SamplesClient(client_wrapper=self._client_wrapper)
        self.text_to_speech = TextToSpeechClient(client_wrapper=self._client_wrapper)
        self.text_to_dialogue = TextToDialogueClient(client_wrapper=self._client_wrapper)
        self.speech_to_speech = SpeechToSpeechClient(client_wrapper=self._client_wrapper)
        self.text_to_voice = TextToVoiceClient(client_wrapper=self._client_wrapper)
        self.user = UserClient(client_wrapper=self._client_wrapper)
        self.voices = VoicesClient(client_wrapper=self._client_wrapper)
        self.studio = StudioClient(client_wrapper=self._client_wrapper)
        self.dubbing = DubbingClient(client_wrapper=self._client_wrapper)
        self.models = ModelsClient(client_wrapper=self._client_wrapper)
        self.audio_native = AudioNativeClient(client_wrapper=self._client_wrapper)
        self.usage = UsageClient(client_wrapper=self._client_wrapper)
        self.pronunciation_dictionaries = PronunciationDictionariesClient(client_wrapper=self._client_wrapper)
        self.service_accounts = ServiceAccountsClient(client_wrapper=self._client_wrapper)
        self.webhooks = WebhooksClient(client_wrapper=self._client_wrapper)
        self.speech_to_text = SpeechToTextClient(client_wrapper=self._client_wrapper)
        self.forced_alignment = ForcedAlignmentClient(client_wrapper=self._client_wrapper)
        self.conversational_ai = ConversationalAiClient(client_wrapper=self._client_wrapper)
        self.music = MusicClient(client_wrapper=self._client_wrapper)
        self.workspace = WorkspaceClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> RawBaseElevenLabs:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBaseElevenLabs
        """
        return self._raw_client

    def save_a_voice_preview(self, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Add a generated voice to the voice library.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.save_a_voice_preview()
        """
        _response = self._raw_client.save_a_voice_preview(request_options=request_options)
        return _response.data


class AsyncBaseElevenLabs:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ElevenLabsEnvironment
        The environment to use for requests from the client. from .environment import ElevenLabsEnvironment



        Defaults to ElevenLabsEnvironment.PRODUCTION



    api_key : typing.Optional[str]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 240 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from elevenlabs import AsyncElevenLabs

    client = AsyncElevenLabs(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ElevenLabsEnvironment = ElevenLabsEnvironment.PRODUCTION,
        api_key: typing.Optional[str] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 240 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = AsyncRawBaseElevenLabs(client_wrapper=self._client_wrapper)
        self.history = AsyncHistoryClient(client_wrapper=self._client_wrapper)
        self.text_to_sound_effects = AsyncTextToSoundEffectsClient(client_wrapper=self._client_wrapper)
        self.audio_isolation = AsyncAudioIsolationClient(client_wrapper=self._client_wrapper)
        self.samples = AsyncSamplesClient(client_wrapper=self._client_wrapper)
        self.text_to_speech = AsyncTextToSpeechClient(client_wrapper=self._client_wrapper)
        self.text_to_dialogue = AsyncTextToDialogueClient(client_wrapper=self._client_wrapper)
        self.speech_to_speech = AsyncSpeechToSpeechClient(client_wrapper=self._client_wrapper)
        self.text_to_voice = AsyncTextToVoiceClient(client_wrapper=self._client_wrapper)
        self.user = AsyncUserClient(client_wrapper=self._client_wrapper)
        self.voices = AsyncVoicesClient(client_wrapper=self._client_wrapper)
        self.studio = AsyncStudioClient(client_wrapper=self._client_wrapper)
        self.dubbing = AsyncDubbingClient(client_wrapper=self._client_wrapper)
        self.models = AsyncModelsClient(client_wrapper=self._client_wrapper)
        self.audio_native = AsyncAudioNativeClient(client_wrapper=self._client_wrapper)
        self.usage = AsyncUsageClient(client_wrapper=self._client_wrapper)
        self.pronunciation_dictionaries = AsyncPronunciationDictionariesClient(client_wrapper=self._client_wrapper)
        self.service_accounts = AsyncServiceAccountsClient(client_wrapper=self._client_wrapper)
        self.webhooks = AsyncWebhooksClient(client_wrapper=self._client_wrapper)
        self.speech_to_text = AsyncSpeechToTextClient(client_wrapper=self._client_wrapper)
        self.forced_alignment = AsyncForcedAlignmentClient(client_wrapper=self._client_wrapper)
        self.conversational_ai = AsyncConversationalAiClient(client_wrapper=self._client_wrapper)
        self.music = AsyncMusicClient(client_wrapper=self._client_wrapper)
        self.workspace = AsyncWorkspaceClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBaseElevenLabs:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBaseElevenLabs
        """
        return self._raw_client

    async def save_a_voice_preview(self, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Add a generated voice to the voice library.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.save_a_voice_preview()


        asyncio.run(main())
        """
        _response = await self._raw_client.save_a_voice_preview(request_options=request_options)
        return _response.data


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ElevenLabsEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .conversations_list_request_summary_mode import ConversationsListRequestSummaryMode

__all__ = ["ConversationsListRequestSummaryMode"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .resources import BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
from . import groups, invites, members, resources
from .invites import BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission
from .members import BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole

__all__ = [
    "BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission",
    "BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole",
    "BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole",
    "groups",
    "invites",
    "members",
    "resources",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .music_compose_detailed_request_output_format import MusicComposeDetailedRequestOutputFormat
from .music_compose_request_output_format import MusicComposeRequestOutputFormat
from .music_stream_request_output_format import MusicStreamRequestOutputFormat

__all__ = [
    "MusicComposeDetailedRequestOutputFormat",
    "MusicComposeRequestOutputFormat",
    "MusicStreamRequestOutputFormat",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .document_usage_mode_enum import DocumentUsageModeEnum
from .get_knowledge_base_summary_url_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
)
from .knowledge_base_document_metadata_response_model import KnowledgeBaseDocumentMetadataResponseModel
from .resource_access_info import ResourceAccessInfo


class GetKnowledgeBaseSummaryUrlResponseModel(UncheckedBaseModel):
    id: str
    name: str
    metadata: KnowledgeBaseDocumentMetadataResponseModel
    supported_usages: typing.List[DocumentUsageModeEnum]
    access_info: ResourceAccessInfo
    dependent_agents: typing.List[GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem]
    url: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    PhoneNumbersCreateRequestBody,
    PhoneNumbersCreateRequestBody_SipTrunk,
    PhoneNumbersCreateRequestBody_Twilio,
    PhoneNumbersGetResponse,
    PhoneNumbersGetResponse_SipTrunk,
    PhoneNumbersGetResponse_Twilio,
    PhoneNumbersListResponseItem,
    PhoneNumbersListResponseItem_SipTrunk,
    PhoneNumbersListResponseItem_Twilio,
    PhoneNumbersUpdateResponse,
    PhoneNumbersUpdateResponse_SipTrunk,
    PhoneNumbersUpdateResponse_Twilio,
)

__all__ = [
    "PhoneNumbersCreateRequestBody",
    "PhoneNumbersCreateRequestBody_SipTrunk",
    "PhoneNumbersCreateRequestBody_Twilio",
    "PhoneNumbersGetResponse",
    "PhoneNumbersGetResponse_SipTrunk",
    "PhoneNumbersGetResponse_Twilio",
    "PhoneNumbersListResponseItem",
    "PhoneNumbersListResponseItem_SipTrunk",
    "PhoneNumbersListResponseItem_Twilio",
    "PhoneNumbersUpdateResponse",
    "PhoneNumbersUpdateResponse_SipTrunk",
    "PhoneNumbersUpdateResponse_Twilio",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission

__all__ = ["BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .text_to_dialogue_convert_request_output_format import TextToDialogueConvertRequestOutputFormat
from .text_to_dialogue_stream_request_output_format import TextToDialogueStreamRequestOutputFormat

__all__ = ["TextToDialogueConvertRequestOutputFormat", "TextToDialogueStreamRequestOutputFormat"]



# This file was auto-generated by Fern from our API Definition.

import typing

ProjectResponseModelSourceType = typing.Union[typing.Literal["blank", "book", "article", "genfm", "video"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from . import knowledge_base, link, llm_usage, widget

__all__ = ["knowledge_base", "link", "llm_usage", "widget"]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.user import User
from .raw_client import AsyncRawUserClient, RawUserClient
from .subscription.client import AsyncSubscriptionClient, SubscriptionClient


class UserClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawUserClient(client_wrapper=client_wrapper)
        self.subscription = SubscriptionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawUserClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawUserClient
        """
        return self._raw_client

    def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> User:
        """
        Gets information about the user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        User
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.user.get()
        """
        _response = self._raw_client.get(request_options=request_options)
        return _response.data


class AsyncUserClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawUserClient(client_wrapper=client_wrapper)
        self.subscription = AsyncSubscriptionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawUserClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawUserClient
        """
        return self._raw_client

    async def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> User:
        """
        Gets information about the user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        User
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.user.get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get(request_options=request_options)
        return _response.data
